#!/bin/bash

set -e

GIT_PATH="$PWD"

TAG="samba-4.4.2"

SVN_PATH_SCRIPT=$(realpath -s $0)
SVN_PATH_TOOLS=$(dirname $SVN_PATH_SCRIPT)
SVN_PATH_PATCHES=$(dirname $SVN_PATH_TOOLS)
SVN_PATH=$(dirname $SVN_PATH_PATCHES)

GUARDS="default_passdb_backend"
SERIES="$($SVN_PATH_TOOLS/guards $GUARDS < $SVN_PATH_PATCHES/series)"

# Check if we are in an expanded git tree, search tag
if [ ! $(git tag -l $TAG) ]; then
	echo "Tag $TAG not found."
	exit 1
fi

# Checkout tag
echo "Checking out $TAG (detached HEAD)"
git checkout -q $TAG 2>&1 > /dev/null

# Copy docs from release tarball
echo "Copying docs from release tarball"
pushd $SVN_PATH 1>/dev/null
make clean
make setup
cp -r build/pac/stable/samba/$TAG/docs $GIT_PATH
popd 1>/dev/null
git add -f docs
git commit -s -m "Import docs from release tarball" -q

# Apply patches
for patch in $SERIES; do
	# Get the line from series file to parse the comment
	line=$(grep $patch $SVN_PATH_PATCHES/series)
	msg=""
	if [[ $line == *[#]* ]]; then
		msg=$(echo $line | sed -e 's/^.*#[[:blank:]]*//')
	fi

	# Apply patch
	echo "Applying $patch"
	patch -E -p0 --no-backup-if-mismatch -i $SVN_PATH_PATCHES/$patch

	# Commit result
	git add .
	git commit -s -m "Import $patch" -m "$msg" -q
done

echo
echo "Done. Remember you are in a detached HEAD state."
